# -*- coding: utf-8 -*-
# Generated by Django 1.9.6 on 2017-02-06 10:06
from __future__ import unicode_literals

import ckeditor.fields
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Article',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('type', models.CharField(choices=[(b'news', 'News')], default=None, max_length=255, verbose_name='\u0422\u0438\u043f')),
                ('title', models.CharField(max_length=255, verbose_name='\u041d\u0430\u0437\u0432\u0430')),
                ('logo', models.ImageField(blank=True, null=True, upload_to=b'article_logos')),
                ('description', models.CharField(max_length=255, verbose_name='\u041e\u043f\u0438\u0441')),
                ('text', ckeditor.fields.RichTextField(max_length=10000, verbose_name='\u0422\u0435\u043a\u0441\u0442')),
            ],
            options={
                'verbose_name': 'Article',
                'verbose_name_plural': 'Articles',
            },
        ),
    ]
